/* $Id$
 *
 * Lasso - A free implementation of the Liberty Alliance specifications.
 *
 * Copyright (C) 2004-2007 Entr'ouvert
 * http://lasso.entrouvert.org
 *
 * Authors: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __LASSO_IDSWF_H__
#define __LASSO_IDSWF_H__

#include "authentication.h"
#include "data_service.h"
#include "discovery.h"
#include "id_ff_extensions.h"
#include "id_wsf.h"
#include "interaction_profile_service.h"
#include "personal_profile_service.h"
#include "wsf_utils.h"
#include "wsf_profile.h"

#endif /* __LASSO_IDSWF_H__ */
